<?php

namespace Teknisa\MAN\Services;

use Teknisa\MAN\Factories\RNFFactory;
use \Exception as Exception;

class RNFService {
    protected $rnfFactory;

    public function __construct(RNFFactory $rnfFactory) {
        $this->rnfFactory = $rnfFactory;
    }

    private function params($conditions) {
        $params = [
            ':CDFILIAL'     => $conditions['CDFILIAL'],
            ':TCDFILIAL'    => $conditions['TCDFILIAL'],
            ':P_DTINI'      => $conditions['P_DTINI'],
            ':P_DTFIN'      => $conditions['P_DTFIN'],
            ':P_NUMINI'     => $conditions['P_NUMINI'],
            ':P_NUMFIN'     => $conditions['P_NUMFIN'],
            ':P_CDOPERADOR' => $conditions['P_CDOPERADOR']
        ];

        return $params;
    }

    public function findFiliais($conditions) {
        $params = $this->params($conditions);
        
        return $this->rnfFactory->findFiliais($params);
    }

    public function findCabecalho($conditions) {
        $params = $this->params($conditions);
        
        return $this->rnfFactory->findCabecalho($params);
    }

    public function findNotas($conditions) {
        $params = $this->params($conditions);
        
        return $this->rnfFactory->findNotas($params);
    }

    public function findItens($conditions) {
        $params = $this->params($conditions);
        
        return $this->rnfFactory->findItens($params);
    }

    public function findImpostos($conditions) {
        $params = $this->params($conditions);
        
        return $this->rnfFactory->findImpostos($params);
    }

    public function gerarRNF($row) {
        $result = [];

        if((isset($row['CDFILIAL'])) && (isset($row['DATAINI'])) && (isset($row['DATAFIN']))) {
            if(is_array($row['CDFILIAL'])) {
                foreach($row['CDFILIAL'] as $filial) {
                    $params = [
                        'CDFILIAL'   => $filial,
                        'DATAINI'    => $row['DATAINI'],
                        'DATAFIN'    => $row['DATAFIN'],
                        'CDOPERADOR' => $row['CDOPERADOR'],
                        'P_CDFILIAL' => $row['P_CDFILIAL'],
                        'TCDFILIAL'  => $row['TCDFILIAL']
                    ];

                    $resultGerarRNF = $this->rnfFactory->gerarRNF($params);
                }
            } else {
                $params = [
                    'CDFILIAL'   => $row['CDFILIAL'],
                    'DATAINI'    => $row['DATAINI'],
                    'DATAFIN'    => $row['DATAFIN'],
                    'CDOPERADOR' => $row['CDOPERADOR'],
                    'P_CDFILIAL' => $row['P_CDFILIAL'],
                    'TCDFILIAL'  => $row['TCDFILIAL']
                ];

                $resultGerarRNF = $this->rnfFactory->gerarRNF($params);
            }

            if($resultGerarRNF) {
                $result = $this->rnfFactory->validaGeracaoRNF($params);
            }

            return $result;
        } else {
            throw new Exception("Faça o filtro na tela nos campos 'Unidade' e 'Data de RNF'");
        }
    }

    public function verificaIntegracao() {
        $status = $this->rnfFactory->verificaIntegracao();
        
        if((!empty($status)) && ($status['STATUS'] == "SUCCEEDED")) {
            return "Integração Online";
        } else {
            return "Integração Offline";
        }        
    }
}